////////////////////////////////
// Setup
////////////////////////////////

// Gulp and package
const { src, dest, parallel, series } = require('gulp')

// Plugins
const concat = require('gulp-concat')
const plumber = require('gulp-plumber')
const rename = require('gulp-rename')
const uglify = require('gulp-uglify-es').default

// Relative paths function
function pathsConfig() {
  const vendorsRoot = 'node_modules'
  const templatesRoot = 'templates'

  return {
    vendorsJs: [
      //`${vendorsRoot}/@sentry/browser/build/bundle.js`,
      `${vendorsRoot}/jquery/dist/jquery.js`,
      `${vendorsRoot}/d3/dist/d3.js`,
      `${vendorsRoot}/mustache/mustache.js`,
      `${vendorsRoot}/bootstrap/dist/js/bootstrap.js`,
      `${vendorsRoot}/@fortawesome/fontawesome-free/js/all.js`,
    ],
    projectJs: [
        `${templatesRoot}/js/custom-publish-gui.js`,
        `${templatesRoot}/js/neologie-interactive.js`,
        `${templatesRoot}/js/neologie.js`,
        `${templatesRoot}/js/sunburst.js`,
    ],
    js: `${templatesRoot}/js`,
  }
}

var paths = pathsConfig()

////////////////////////////////
// Tasks
////////////////////////////////

// Javascript minification
function scripts() {
    return src(paths.projectJs)
      .pipe(concat('project.js'))
      .pipe(dest(paths.js))
      .pipe(plumber()) // Checks for errors
      .pipe(uglify()) // Minifies the js
      .pipe(rename({ suffix: '.min' }))
      .pipe(dest(paths.js))
  }


// Vendor Javascript minification
function vendorScripts() {
  return src(paths.vendorsJs)
    .pipe(concat('vendors.js'))
    .pipe(dest(paths.js))
    .pipe(plumber()) // Checks for errors
    .pipe(uglify()) // Minifies the js
    .pipe(rename({ suffix: '.min' }))
    .pipe(dest(paths.js))
}


// Generate all assets
const generateAssets = parallel(
  scripts,
  vendorScripts
)

exports.default = series(generateAssets)
exports["generate-assets"] = generateAssets

